@@ -1,17 +1,16 @@
 #Step2-1-2-1:Fitting with 1-Compartment PK Model:  1-Compartment menu -->noniv route menu-->Extravascular, SD, & 1-Ord Abs w Tlag 
 ffirst.lag<- function(InVVRefindex,
-                      Dose=NULL, 
-                      ka=NULL,
-                      Vm=NULL,Km=NULL, # MMe=TRUE
-                      Vd=NULL,
-                      kel=NULL,        # MMe=FALSE
-                      Tlag=TRUE,
-                      MMe=FALSE) 
+                      Dose     = NULL, 
+                      ka       = NULL,
+                      Vd       = NULL,
+                      kel      = NULL,
+                      lag_time = NULL,
+                      Tlag     = TRUE)
 {
-   #options(warn=-1)  \ON
+   options(warn=-1)
    modfun<-NULL
    
-   ## Input dose and Tlag and initial value for ka, kel and Vd
+   ## Input dose and lag_time and initial value for ka, kel and Vd
    if (is.null(Dose)) {
      cat("Enter Dose value\n")
      Dose <- scan(nlines=1,quiet=TRUE)
@@ -19,9 +18,9 @@ ffirst.lag<- function(InVVRefindex,
    else {
      cat("Dose = ",Dose,"\n")
    }
-   if (Tlag){
+   if(Tlag){
        cat("\nEnter lag time value\n")
-       Tlag<-scan(nlines=1,quiet=TRUE)
+       lag_time<-scan(nlines=1,quiet=TRUE)
        cat("\n")
    } 
      
@@ -37,7 +36,7 @@ ffirst.lag<- function(InVVRefindex,
      if (Tlag){
       ## User-supplied function w/o MM elimination w lag time
       defun<- function(time, y, parms) { 
-      if(time<=Tlag) {
+      if(time<=lag_time) {
        dy1dt<-0
        dy2dt<-0
       }
@@ -75,18 +74,17 @@ ffirst.lag<- function(InVVRefindex,
 
    with(entertitle(),{
 
-   ka<-NULL
-   ke<-NULL
-   Vd<-NULL
-   Vm<-NULL
-   Km<-NULL
+   ka <-NULL
+   kel<-NULL
+   Vd <-NULL
    sub<-NULL
+
    for( i in 1:length(unique(InVVRefindex$subj)))  {
       cat("\n\n               << subject",i,">>\n\n" )
       sub[i]<-i  
       objfun <- function(par) {
       out <- modfun(InVVRefindex$time[InVVRefindex$subj==i], par[1], par[2], par[3])
-      gift <- which(InVVRefindex$conc[InVVRefindex$subj==i] != 0 )
+      gift <- which(InVVRefindex$conc[InVVRefindex$subj==i] != 0)
       switch(pick,
             sum((InVVRefindex$conc[InVVRefindex$subj==i][gift]-out[gift])^2),
             sum((InVVRefindex$conc[InVVRefindex$subj==i][gift]-out[gift])^2/InVVRefindex$conc[gift]),
@@ -94,24 +92,20 @@ ffirst.lag<- function(InVVRefindex,
       }
 
 ## fitted by Nelder-Mead Simplex algorithm
-        opt<-optim(c(par[1,2],par[2,2],par[3,2]),objfun, method="Nelder-Mead") 
+        opt<-optimx(c(par[1,2],par[2,2],par[3,2]),objfun, method="Nelder-Mead") 
         nameopt<-c("ka","kel","Vd")
-        outopt<-c(opt$par[1],opt$par[2],opt$par[3])
+        outopt<-c(opt$p1,opt$p2,opt$p3)
         
-        ka[i]<- opt$par[1]
-        ke[i]<- opt$par[2]
-        Vd[i]<- opt$par[3]
-
-        if(opt$par[1]<0) opt$par[1]<-0.001
-        if(opt$par[2]<0) opt$par[2]<-0.001
-        if(opt$par[3]<0) opt$par[3]<-0.001
+        if(opt$p1<0) opt$p1<-0.0001
+        if(opt$p2<0) opt$p2<-0.0001
+        if(opt$p3<0) opt$p3<-0.0001
         
         conc<-InVVRefindex$conc[InVVRefindex$subj==i]
         time<-InVVRefindex$time[InVVRefindex$subj==i]
         
-        if(pick==1) weights=(1/conc^0)  ### equal weight
-        if(pick==2) weights=(1/conc^1)  ### 1/Cp
-        if(pick==3) weights=(1/conc^2)  ### 1/Cp^2
+        if(pick==1) weights<- ifelse(conc==0.,1,1/conc^0)  ### equal weight
+        if(pick==2) weights<- ifelse(conc==0.,1,1/conc^1)  ### 1/Cp
+        if(pick==3) weights<- ifelse(conc==0.,1,1/conc^2)  ### 1/Cp^2
         
       cat("\n<< The value of parameter fitted by Nelder-Mead Simplex algorithm >>\n\n")
       print(data.frame(Parameter=nameopt,Value=outopt))
@@ -119,21 +113,21 @@ ffirst.lag<- function(InVVRefindex,
 ##Residuals sum-of-squares and parameter values fitted by nls 
       cat("\n<< Residual sum-of-squares and parameter values fitted by nlsLM >>\n\n")
 ## No MM elimination
-        fm <-nlsLM(conc ~ modfun(time, ka, ke, Vd), data=subset(InVVRefindex,subj==i),
-             start=list(ka=opt$par[1],ke=opt$par[2],Vd=opt$par[3]),weights=weights,
-             control=nls.lm.control(maxiter=500),lower=c(1e-06,1e-06,1e-06))
+        fm <-nlsLM(conc ~ modfun(time, ka, kel, Vd), data=subset(InVVRefindex,subj==i),
+             start=list(ka=opt$p1,kel=opt$p2,Vd=opt$p3),weights=weights,
+             control=nls.lm.control(maxiter=500,maxfev=5000),lower=c(1e-06,1e-06,1e-06))
         cat("\n")
-        ka[i]<-data.frame(coef(fm)["ka"])[1,1]  ### extract ka value from fm
-        ke[i]<-data.frame(coef(fm)["ke"])[1,1]  ### extract ke value from fm
-        Vd[i]<-data.frame(coef(fm)["Vd"])[1,1]  ### extract Vd value from fm
-        coef <-data.frame(coef(fm)["ke"])
+        ka[i] <-data.frame(coef(fm)["ka"])[1,1]   ### extract ka value from fm
+        kel[i]<-data.frame(coef(fm)["kel"])[1,1]  ### extract kel value from fm
+        Vd[i] <-data.frame(coef(fm)["Vd"])[1,1]   ### extract Vd value from fm
+        coef  <-data.frame(coef(fm)["kel"])
         plotting.lin(InVVRefindex, fm, i, pick, coef, xaxis, yaxis)
 
  }        
           cat("<< Summary >>\n")
-          keindex<-data.frame(subj=sub,ka=ka,kel=ke,Vd=Vd)
+          keindex<-data.frame(subj=sub,ka=ka,kel=kel,Vd=Vd)
           show(keindex)
-          kename<-"ivivc_pk_values.RData"                  ### however this will overwrite previously saved data. -YJ
+          kename<-"ivivc_pk_values.RData"       ### however this will overwrite previously saved data. -YJ
           saveRDS(keindex,kename)
 }) 
 cat("\n\n")
