@@ -2,7 +2,8 @@
 noniv.route <- function(InVVRefindex)
 {
   
-  file.menu <- c("Extravascular, single-dose, 1-Ordered absorption wihtout lag time",
+  file.menu <- c("Extravascular, single-dose, 1-Ordered absorption without lag time",
+                 "Extravascular, single-dose, 1-Ordered absorption with lag time",
                  "Go back One Upper Level")
   cat("\n")
   pick <- menu(file.menu, title = "<< Non IV Route >>")
@@ -11,7 +12,9 @@ noniv.route <- function(InVVRefindex)
      ffirst.nolag(InVVRefindex)
   }
   else if (pick == 2){
+     ffirst.lag(InVVRefindex)
+  }
+  else if (pick == 3){
      one.list(InVVRefindex)
   }
-  
 }
\ No newline at end of file
